% plotGMM(weight, mean, variance, singleGaussians, resolution)
% 
% plots the values of a 1D normal distribution; if resolution is not given,
% the curve is sampled with 1000 points between +-3*variance, otherwise
% the number of points given is used; if jointDensity is given ==1,
% the joint densitiy is plotted instead of the single weighted gaussian
% mixtures
% copyright (c) 2008 by thilo stadelmann, stadelmann@informatik.uni-marburg.de

function plotGMM(weight, mean, variance, jointDensity, resolution)

if (nargin < 5)
    r = 1000;    
else
    r = resolution;
end

if (nargin < 4)
    simple = 0;
else
    simple = jointDensity;
end

%define all possibilities for line-drawing styles that plot() recognizes
colors = {'b' 'g' 'r' 'c' 'm' 'y' 'k'};
lines = {'-' ':' '-.' '--'};
%symbols = {' ' '.' 'o' 'x' '+' '*' 's' 'd' 'v' '^' '<' '>' 'p' 'h'};

dim = length(mean(1, :)); %columns of the mean matrix are feature dimensions
mixtures = length(mean(:, 1)); %rows of the mean matrix are mixture components
gridDim = max(floor(sqrt(dim))-1, 1); %number of cols in the plot grid

if (simple == 0) 
    %draw individual gaussians, one subplot per dimension
    figure;
    subplot(dim/gridDim, gridDim, 1);
    for d = 1:dim,
        cc = 1; %color-counter
        lc = 1; %linesytle-counter
        %sc = 1; %dotsymbol-counter
    
        subplot(dim/gridDim, gridDim, d);
        hold on;
        for m = 1:mixtures,
            style = sprintf('%s%s', colors{cc}, lines{lc}); %, symbols{sc});
            plotNormal1d(mean(m, d), variance(m, d), r, weight(m), style);
        
            %change the style of the next curve to plot: 
            cc = cc+1; %first, rotate colors
            if (cc > length(colors))
                cc = 1; 
                lc = lc+1; %then, use the same colors again using different line styles; 
                if (lc > length(lines))
                    lc = 1;
                    %sc = sc+1; %last, use different symbols
                    cc = 1; %last start all over again
                end
            end
        end
        hold off;
        s = sprintf('dim %d', d-1);
        title(s);
    end
else
    %draw complete GMM density per dimension
    figure;
    subplot(dim/gridDim, gridDim, 1);
    for d = 1:dim,
        subplot(dim/gridDim, gridDim, d);
        plotGMM1d(weight, mean(:, d), variance(:, d), r);
        s = sprintf('dim %d', d-1);
        title(s);
    end
end
