% plotNormal1d(mean, variance, resolution, weight, style)
% 
% plots the values of a 1D normal distribution; if resolution is not given,
% the curve is sampled with 1000 points, otherwise the number of points 
% given is used; if weight is given (0<weight<=1), the gaussian is scaled 
% accordingly; if style is given, the curve is plotted using this style 
% (color and linestyle); if zero is given, this value is used as the 
% minimum y value to plot, (i.e. it determines the width of the plotted 
% distribution)
% copyright (c) 2008 by thilo stadelmann, stadelmann@informatik.uni-marburg.de

function plotNormal1d(mean, variance, resolution, weight, style, zero)

if (nargin < 6)
    z = 0.0001;
else
    z = zero; 
end

if (nargin < 5)
    s = 'b-';
else
    s = style;
end

if (nargin < 4)
    w = 1.0;
else 
    w = weight;
end

deltaX = sqrt(-2.0*variance*(log(z)-log(1/sqrt(2*pi*variance)))); %this +- mean is the x-value where y reaches z, the minimum y-value to plot

if (nargin <3)
    t = 2*deltaX / 1000;    
else
    t = 2*deltaX / resolution;
end

x = [mean-deltaX : t : mean+deltaX];
data = normal1d(x, mean, variance) * w;
plot(x, data, s);
